package dev.fitko.fitconnect.client.steps.subscriber;

import dev.fitko.fitconnect.api.domain.model.event.Event;
import dev.fitko.fitconnect.api.domain.model.event.problems.Problem;
import dev.fitko.fitconnect.api.domain.model.submission.ReceivedSubmission;

import java.util.List;
import java.util.Optional;
public interface ConfirmSubmissionStep {

    /**
     * Send an accept-submission {@link Event} to confirm that the handed in submission was accepted.
     *
     * @see <a href="https://docs.fitko.de/fit-connect/docs/getting-started/event-log/events">FIT-Connect Events</a>
     */
    void acceptSubmission();

    /**
     * Send a reject-submission {@link Event} to confirm that the handed in submission was rejected.
     *
     * @param problems list of {@link Problem}s that give more detailed information on why the submission was rejected
     *
     * @see <a href="https://docs.fitko.de/fit-connect/docs/getting-started/event-log/events">FIT-Connect Events</a>
     */
    void rejectSubmission(List<Problem> problems);

    /**
     * Get the submission data and attachments.
     *
     * @return optional {@link ReceivedSubmission}
     */
    Optional<ReceivedSubmission> getSubmissionData();

    /**
     * Get a list of {@link Problem}s that occrured during the retrieval, decryption or validation of a submission.
     *
     * @return List of {@link Problem}s
     */
    List<Problem> getProblems();
}